#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

from macaroon.playback import *
import utils

sequence = MacroSequence()

sequence.append(PauseAction(3000))
sequence.append(TypeAction("vim"))
sequence.append(KeyComboAction("Return"))
sequence.append(PauseAction(3000))

# KNOWN ISSUE: Sometimes we display the frame and sometimes we don't.
# It seems to be a timing issue.

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("a"))
sequence.append(utils.AssertPresentationAction(
    "1. A to append text",
    ["BRAILLE LINE:  'gnome-terminal-server application \w+@\w+:/tmp/gnome-terminal-wd frame '",
     "     VISIBLE:  '(frame |)', cursor=1",
     "SPEECH OUTPUT: '-- INSERT --                                                  0,1  '"]))

sequence.append(TypeAction("Hi H"))
sequence.append(utils.StartRecordingAction())
sequence.append(TypeAction("i"))
sequence.append(utils.AssertPresentationAction(
    "2. Finish typing 'Hi Hi'",
    ["BRAILLE LINE:  'gnome-terminal-server application \w+@\w+:/tmp/gnome-terminal-wd frame Hi Hi'",
     "     VISIBLE:  '(frame |)Hi Hi', cursor=(6|12)",
     "BRAILLE LINE:  'gnome-terminal-server application \w+@\w+:/tmp/gnome-terminal-wd frame Hi Hi'",
     "     VISIBLE:  '(frame |)Hi Hi', cursor=(6|12)"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("BackSpace"))
sequence.append(utils.AssertPresentationAction(
    "3. BackSpace",
    ["BRAILLE LINE:  'gnome-terminal-server application \w+@\w+:/tmp/gnome-terminal-wd frame Hi H'",
     "     VISIBLE:  '(frame |)Hi H', cursor=(5|11)",
     "BRAILLE LINE:  'gnome-terminal-server application \w+@\w+:/tmp/gnome-terminal-wd frame Hi H'",
     "     VISIBLE:  '(frame |)Hi H', cursor=(5|11)",
     "BRAILLE LINE:  'gnome-terminal-server application \w+@\w+:/tmp/gnome-terminal-wd frame Hi H'",
     "     VISIBLE:  '(frame |)Hi H', cursor=(5|11)",
     "SPEECH OUTPUT: 'i'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("BackSpace"))
sequence.append(utils.AssertPresentationAction(
    "4. BackSpace",
    ["BRAILLE LINE:  'gnome-terminal-server application \w+@\w+:/tmp/gnome-terminal-wd frame Hi '",
     "     VISIBLE:  '(frame |)Hi ', cursor=(4|10)",
     "BRAILLE LINE:  'gnome-terminal-server application \w+@\w+:/tmp/gnome-terminal-wd frame Hi '",
     "     VISIBLE:  '(frame |)Hi ', cursor=(4|10)",
     "BRAILLE LINE:  'gnome-terminal-server application \w+@\w+:/tmp/gnome-terminal-wd frame Hi '",
     "     VISIBLE:  '(frame |)Hi ', cursor=(4|10)",
     "SPEECH OUTPUT: 'H'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("BackSpace"))
sequence.append(utils.AssertPresentationAction(
    "5. BackSpace",
    ["KNOWN ISSUE: We're speaking '4', possibly due to a heuristic",
     "BRAILLE LINE:  'gnome-terminal-server application \w+@\w+:/tmp/gnome-terminal-wd frame Hi '",
     "     VISIBLE:  '(frame |)Hi ', cursor=(3|9)",
     "BRAILLE LINE:  'gnome-terminal-server application \w+@\w+:/tmp/gnome-terminal-wd frame Hi '",
     "     VISIBLE:  '(frame |)Hi ', cursor=(3|9)",
     "BRAILLE LINE:  'gnome-terminal-server application \w+@\w+:/tmp/gnome-terminal-wd frame Hi '",
     "     VISIBLE:  '(frame |)Hi ', cursor=(3|9)",
     "SPEECH OUTPUT: '4'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(TypeAction("!"))
sequence.append(utils.AssertPresentationAction(
    "6. Type '!'",
    ["BRAILLE LINE:  'gnome-terminal-server application \w+@\w+:/tmp/gnome-terminal-wd frame Hi!'",
     "     VISIBLE:  '(frame |)Hi!', cursor=(4|10)",
     "BRAILLE LINE:  'gnome-terminal-server application \w+@\w+:/tmp/gnome-terminal-wd frame Hi!'",
     "     VISIBLE:  '(frame |)Hi!', cursor=(4|10)"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Return"))
sequence.append(utils.AssertPresentationAction(
    "7. Return",
    ["BRAILLE LINE:  ''",
     "     VISIBLE:  '', cursor=1",
     "BRAILLE LINE:  ''",
     "     VISIBLE:  '', cursor=1"]))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
