#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Test of spin button output"""

from macaroon.playback import *
import utils

sequence = MacroSequence()

sequence.append(KeyComboAction("<Control>f"))
sequence.append(TypeAction("Printing"))
sequence.append(KeyComboAction("Return"))
sequence.append(KeyComboAction("<Alt>s"))
sequence.append(KeyComboAction("Tab"))
sequence.append(PauseAction(2000))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("<Alt>s"))
sequence.append(utils.AssertPresentationAction(
    "1. Give focus to spin button",
    ["BRAILLE LINE:  'gtk-demo application Print dialog General page tab Copies: 1 $l'",
     "     VISIBLE:  'Copies: 1 $l', cursor=10",
     "SPEECH OUTPUT: 'Copies: 1 selected spin button.'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("KP_Enter"))
sequence.append(utils.AssertPresentationAction(
    "2. Where Am I",
    ["BRAILLE LINE:  'gtk-demo application Print dialog General page tab Copies: 1 $l'",
     "     VISIBLE:  'Copies: 1 $l', cursor=10",
     "SPEECH OUTPUT: 'Copies: spin button 1 selected.'",
     "SPEECH OUTPUT: 'Alt+S'"]))

sequence.append(TypeAction("15"))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Up"))
sequence.append(utils.AssertPresentationAction(
    "3. Increment value",
    ["BRAILLE LINE:  'gtk-demo application Print dialog General page tab Copies: 16 $l'",
     "     VISIBLE:  'Copies: 16 $l', cursor=9",
     "SPEECH OUTPUT: '16'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Down"))
sequence.append(utils.AssertPresentationAction(
    "4. Decrement value",
    ["BRAILLE LINE:  'gtk-demo application Print dialog General page tab Copies: 15 $l'",
     "     VISIBLE:  'Copies: 15 $l', cursor=9",
     "SPEECH OUTPUT: '15'"]))

sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Right"))
sequence.append(utils.AssertPresentationAction(
    "5. Caret navigation",
    ["BRAILLE LINE:  'gtk-demo application Print dialog General page tab Copies: 15 $l'",
     "     VISIBLE:  'Copies: 15 $l', cursor=10",
     "SPEECH OUTPUT: '5'"]))

sequence.append(KeyComboAction("<Alt>F4"))

sequence.append(utils.AssertionSummaryAction())
sequence.start()
